# GOAL: simulate two new patients cohorts 
# (with different covariates compared to the original data set). 
# The first cohort are patients with a quite good karno score, around 70, 
# and mostly with squamous cell type (70% squamous, 10% adeno, 10% smallcell,
# 10% large). The second cohort are patients having mostly adeno or smallcell 
# celltypes (40% adeno, 40% smallcell, 10% large, 10% squamous) and a low karno score, around 40.

# loading the mlxR library
library(RsSimulx)

# defining the path to the mlxtran project file
project.file <- "./monolixproject/project_veteran_3_celltype_karno.mlxtran"

#========== defining group 1
# covariate data frame for group 1, with column id and one column per covariate
cov1 <- data.frame(id=1:137,
                   karno = rnorm(137,mean=70, sd=5),
                   celltype = c(rep("squamous",100),rep("large",12),rep("smallcell",12),rep("adeno",13))) 

#============= calling simulx for group 1
res1 <- simulx(project = project.file,
              parameter = cov1)

#========== defining group 2
# covariate data frame for group 2, with column id and one column per covariate
cov2 <- data.frame(id=1:137,
                   karno = rnorm(137,mean=40, sd=5),
                   celltype = c(rep("squamous",18),rep("large",19),rep("smallcell",50),rep("adeno",50)))  

#============= calling simulx
res2 <- simulx(project = project.file,
              parameter = cov2)

# Putting together the results of the two groups
res1$Event$group <- as.factor(1)
res2$Event$group <- as.factor(2)
res2$Event$id <- as.factor(as.integer(res2$Event$id) + 100)
EvRes <- rbind(res1$Event,res2$Event)

#============= plotting the KM survival curve
group.labels <- c("high karno, mostly squamous", "low karno, mostly adeno and smallcell")
kmplotmlx(EvRes,labels=group.labels,facet=FALSE) + xlab("Time (days)") + ylab("Survival") + theme(legend.justification=c(1,1), legend.position=c(0.9,0.9))
