# GOAL: doing replicates to assess the uncertainty

# loading the mlxR library
library(RsSimulx)

# defining the path to the mlxtran project file
project.file <- "./monolixproject/project_veteran_3_celltype_karno.mlxtran"

#========== defining group 1
# covariate data frame for group 1, with column id and one column per covariate
# covariate data frame for group 1, with column id and one column per covariate
cov1 <- data.frame(id=1:137,
                   karno = rnorm(137,mean=70, sd=5),
                   celltype = c(rep("squamous",100),rep("large",12),rep("smallcell",12),rep("adeno",13))) 

#============= calling simulx for group 1
res1 <- simulx(project = project.file,
               parameter = cov1,
               group = list(size=50),
               nrep = 100)

#========== defining group 2
# covariate data frame for group 2, with column id and one column per covariate
cov2 <- data.frame(id=1:137,
                   karno = rnorm(137,mean=40, sd=5),
                   celltype = c(rep("squamous",18),rep("large",19),rep("smallcell",50),rep("adeno",50))) 

#============= calling simulx
res2 <- simulx(project = project.file,
               parameter = cov2,
               group = list(size=50),
               nrep = 100)


#============= calculating the KM survival curve
kmout1 <- kmplotmlx(res1$Event,time=seq(0,1000,by=10),facet=FALSE, plot=FALSE) 
kmout2 <- kmplotmlx(res2$Event,time=seq(0,1000,by=10),facet=FALSE, plot=FALSE)
kmout1$surv$group <- as.factor(1)
kmout2$surv$group <- as.factor(2)
kmout2$surv$rep <- as.factor(as.integer(kmout2$surv$rep) + 100)
kmout<- rbind(kmout1$surv,kmout2$surv)

colnames(kmout)[1] <- "id"
attr(kmout,"name") <- "S"
kmout$S[is.na(kmout$S)] <- 0


#============= using prctilemlx to draw prediction interval
group.labels <- c("high karno, mostly squamous", "low karno, mostly adeno and smallcell")

prctilemlx(kmout, labels=group.labels, color="#194280")+ xlab("Time (days)") + ylab("Survival") 

